@@ -1,6 +1,7 @@
 import ntpath
 import os
 import requests
+import sys
 import time
 
 
@@ -236,7 +237,9 @@ class Client:
             headers = self._headers.copy()
             headers["Authorization"] = "Bearer %s" % token
             response = requests.post(
-                "%s/commands" % self._admin_api, headers=headers, json=params,
+                "%s/commands" % self._admin_api,
+                headers=headers,
+                json=params,
             )
             response.raise_for_status()
             return response.json()
@@ -257,7 +260,9 @@ class Client:
             headers = self._headers.copy()
             headers["Authorization"] = "Bearer %s" % token
             response = requests.post(
-                "%s/commands/query" % self._admin_api, headers=headers, json=params,
+                "%s/commands/query" % self._admin_api,
+                headers=headers,
+                json=params,
             )
             response.raise_for_status()
             return response.json()
@@ -276,12 +281,17 @@ class Client:
             }
         }
         """
+
         def call(token):
             headers = self._headers.copy()
             headers["Authorization"] = "Bearer %s" % token
             response = requests.post(
-                "%s/intervention-responses" % self._admin_api, headers=headers, json=params)
+                "%s/intervention-responses" % self._admin_api,
+                headers=headers,
+                json=params,
+            )
             return response.json()
+
         return self._authenticate_request(call)
 
     def create_intervention_request(self, params):
@@ -296,14 +306,16 @@ class Client:
             "data": {
                 "instruction": "Look at the users item on the table"
             }
-        }  
+        }
         """
 
         def call(token):
             headers = self._headers.copy()
             headers["Authorization"] = "Bearer %s" % token
             response = requests.post(
-                "%s/intervention-requests" % self._admin_api, headers=headers, json=params
+                "%s/intervention-requests" % self._admin_api,
+                headers=headers,
+                json=params,
             )
             return response.json()
 
@@ -316,7 +328,9 @@ class Client:
             "tokenExpirationSeconds": 3600,
         }
         response = requests.post(
-            "%s/auth/login" % self._admin_api, headers=self._headers, json=payload,
+            "%s/auth/login" % self._admin_api,
+            headers=self._headers,
+            json=payload,
         )
         response.raise_for_status()
         result = response.json()
@@ -334,6 +348,11 @@ class Client:
         except requests.exceptions.HTTPError as error:
             if error.response.status_code == 401:
                 self._authenticate()
-                return call(self._token)
+                try:
+                    return call(self._token)
+                except requests.exceptions.HTTPError as error:
+                    print(error.response.text, file=sys.stderr)
+                    raise error
             else:
+                print(error.response.text, file=sys.stderr)
                 raise error
